==> pygts-0.1.4.tar.gz: pygts-0.1.4/examples/plotgts.py <==
#! /usr/bin/env python

"""plotgts - plots the contents of a gts file

  Copyright (C) 2009 Thomas J. Duck
  All rights reserved.

  Thomas J. Duck <tom.duck@dal.ca>
  Department of Physics and Atmospheric Science,
  Dalhousie University, Halifax, Nova Scotia, Canada, B3H 3J5

NOTICE

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
"""

import sys

import numpy

from enthought.mayavi import mlab
import gts

if len(sys.argv)!=2:
    print 'Usage: python plotfile GTSFILE'
fname = sys.argv[1]

print '\n\nReading',fname,'...',
sys.stdout.flush()

f = open(fname)
s = gts.Surface()
s.read(f)
f.close()

print 'Done.'
sys.stdout.flush()

print 'Splitting into separate connected and manifold surfaces...',
sys.stdout.flush()

surfaces = s.split()

print 'Done.'
sys.stdout.flush()

for i,s in enumerate(surfaces):
    print '\tSurface',i,'is',
    if s.is_closed():
        print 'closed.'
    else:
        print 'open.'


# Function to convert data between gts to mayavi formats
def get_mayavi_coords_and_triangles(s):
    vertices = s.vertices()
    coords = [v.get() for v in vertices]
    triangles = s.face_indices(vertices)
    x,y,z = zip(*coords)
    return x,y,z,triangles


print 'Retrieving mayavi data...',
sys.stdout.flush()

args = []
for s in surfaces:
    args.append(get_mayavi_coords_and_triangles(s))

print 'Done.'
sys.stdout.flush()

# Plot the surfaces
print 'Plotting...',
sys.stdout.flush()
for s,arg in zip(surfaces,args):
    x,y,z,t = arg
    mlab.triangular_mesh(x,y,z,t,color=(0.5,0.5,0.75))
mlab.show()
print 'Done.'
sys.stdout.flush()

==> pygts-0.3.0.tar.gz: pygts-0.3.0/examples/plotgts.py <==
#! /usr/bin/env python

"""plotgts - plots the contents of a gts file

  Copyright (C) 2009 Thomas J. Duck
  All rights reserved.

  Thomas J. Duck <tom.duck@dal.ca>
  Department of Physics and Atmospheric Science,
  Dalhousie University, Halifax, Nova Scotia, Canada, B3H 3J5

NOTICE

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
"""

import sys

import numpy

from enthought.mayavi import mlab
import gts

if len(sys.argv)!=2:
    print 'Usage: python plotfile GTSFILE'
fname = sys.argv[1]

print '\n\nReading',fname,'...',
sys.stdout.flush()

f = open(fname)
s = gts.Surface()
s = gts.read(f)
f.close()

print 'Done.'
sys.stdout.flush()

print 'Splitting into separate connected and manifold surfaces...',
sys.stdout.flush()

surfaces = s.split()

print 'Done.'
sys.stdout.flush()

#for i,s in enumerate(surfaces):
#    print '\tSurface',i,'is',
#    if s.is_closed():
#        print 'closed.'
#    else:
#        print 'open.'

print 'Retrieving mayavi data...',
sys.stdout.flush()

args = []
for s in surfaces:
    args.append(gts.get_coords_and_face_indices(s,True))

print 'Done.'
sys.stdout.flush()

# Plot the surfaces
print 'Plotting...',
sys.stdout.flush()
for s,arg in zip(surfaces,args):
    x,y,z,t = arg
    mlab.triangular_mesh(x,y,z,t,color=(0.5,0.5,0.75))
mlab.show()
print 'Done.'
sys.stdout.flush()
